@@ -7,18 +7,18 @@ import (
 )
 
 func TestDontFragment(t *testing.T) {
-	var DontFragment DontFragmentAttr
+	var dontFrag DontFragment
 
 	t.Run("False", func(t *testing.T) {
 		m := new(stun.Message)
 		m.WriteHeader()
-		if DontFragment.IsSet(m) {
+		if dontFrag.IsSet(m) {
 			t.Error("should not be set")
 		}
 	})
 	t.Run("AddTo", func(t *testing.T) {
 		m := new(stun.Message)
-		if err := DontFragment.AddTo(m); err != nil {
+		if err := dontFrag.AddTo(m); err != nil {
 			t.Error(err)
 		}
 		m.WriteHeader()
@@ -27,11 +27,11 @@ func TestDontFragment(t *testing.T) {
 			if _, err := decoded.Write(m.Raw); err != nil {
 				t.Fatal("failed to decode message:", err)
 			}
-			if !DontFragment.IsSet(m) {
+			if !dontFrag.IsSet(m) {
 				t.Error("should be set")
 			}
 			if wasAllocs(func() {
-				DontFragment.IsSet(m)
+				dontFrag.IsSet(m)
 			}) {
 				t.Error("unexpected allocations")
 			}
